==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/LegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { LegendDescription } from "./LegendDescription";
/**
 * @hidden
 */
var LegendDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LegendDescriptionMetadata, _super);
    function LegendDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LegendDescriptionMetadata.e = function (a) {
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
    };
    LegendDescriptionMetadata.b = function (a) {
        if (LegendDescriptionMetadata.a == null) {
            LegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LegendDescriptionMetadata.c(LegendDescriptionMetadata.a);
        }
        if (a.g(LegendDescriptionMetadata.a)) {
            return;
        }
        a.s(LegendDescriptionMetadata.a);
    };
    LegendDescriptionMetadata.c = function (a) {
        LegendBaseDescriptionMetadata.c(a);
        a.item("Orientation", "ExportedType:string:LegendOrientation");
        a.item("Orientation@names", "Horizontal;Vertical");
        a.item("TextColor", "String");
        a.item("TextStyle", "String");
        LegendDescriptionMetadata.e(a);
    };
    LegendDescriptionMetadata.d = function (a) {
        LegendDescriptionMetadata.b(a);
        a.u("Legend", function () { return new LegendDescription(); });
        a.t("Legend", LegendDescriptionMetadata.a);
    };
    LegendDescriptionMetadata.$t = markType(LegendDescriptionMetadata, 'LegendDescriptionMetadata');
    LegendDescriptionMetadata.a = null;
    return LegendDescriptionMetadata;
}(Base));
export { LegendDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/LegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { LegendDescription } from "./LegendDescription";
/**
 * @hidden
 */
var LegendDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LegendDescriptionMetadata, _super);
    function LegendDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LegendDescriptionMetadata.e = function (a) {
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
    };
    LegendDescriptionMetadata.b = function (a) {
        if (LegendDescriptionMetadata.a == null) {
            LegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LegendDescriptionMetadata.c(LegendDescriptionMetadata.a);
        }
        if (a.j(LegendDescriptionMetadata.a)) {
            return;
        }
        a.y(LegendDescriptionMetadata.a);
    };
    LegendDescriptionMetadata.c = function (a) {
        LegendBaseDescriptionMetadata.c(a);
        a.item("Orientation", "ExportedType:string:LegendOrientation");
        a.item("Orientation@names", "Horizontal;Vertical");
        a.item("TextColor", "String");
        a.item("TextStyle", "String");
        LegendDescriptionMetadata.e(a);
    };
    LegendDescriptionMetadata.d = function (a) {
        LegendDescriptionMetadata.b(a);
        a.aa("Legend", function () { return new LegendDescription(); });
        a.z("Legend", LegendDescriptionMetadata.a);
    };
    LegendDescriptionMetadata.$t = markType(LegendDescriptionMetadata, 'LegendDescriptionMetadata');
    LegendDescriptionMetadata.a = null;
    return LegendDescriptionMetadata;
}(Base));
export { LegendDescriptionMetadata };
